@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php.h 321634 2012-01-01 13:15:04Z felipe $ */
+/* $Id$ */
 
 #ifndef PHP_H
 #define PHP_H
@@ -60,14 +60,9 @@
 #	else
 #		define PHPAPI
 #	endif
-
-#define THREAD_LS
-#define PHP_DIR_SEPARATOR '/'
-#if defined(__MacOSX__)
-#define PHP_EOL "\r"
-#else 
-#define PHP_EOL "\n"
-#endif
+#	define THREAD_LS
+#	define PHP_DIR_SEPARATOR '/'
+#	define PHP_EOL "\n"
 #endif
 
 #ifdef NETWARE
